<?php

/**
 * FluxBB File Uploader v1.1.1
 * A simple plugin to upload files
 * Copyright (C) Loïc Dagallier
 * Compatible with FluxBB 1.4.3+ and 1.5
 * License: http://www.gnu.org/licenses/gpl.html GPL version 2 or higher
 */

//define('PUN_SHOW_QUERIES', 1);
//define('PUN_DEBUG', 1);

define('FFU_VERSION', '1.1.1');

/*******************************/
/****  START CONFIGURATION  ****/
/*******************************/

// Maintenance mode
define ('MAINTENANCE', false);

// Uploads directory
define('UPLOAD_ROOT', 'img/uploads/');

// Min and Max file sizes in bytes
// Ckeck your PHP Configuration file
// before change these settings
define('UPLOAD_MIN_SIZE', 10);
define('UPLOAD_MAX_SIZE', 20971520);

// Max height and width of images in pixels
define('IMG_MAX_HEIGHT', 1024);
define('IMG_MAX_WIDTH', 1024);

// Uploaded files must be renamed ?
// (SHOULD ALWAYS BE 'true' FOR SECURITY REASONS)
define('RENAME_FILE', true);

// A user can delete their own files ?
define('ALLOW_USER_DELETE_OWN_FILES', true);

// Can we delete a file in use (in a post) ?
define('ALLOW_DELETE_FILE_IN_USE', false);

// Images allowed (note that *.ico is only supported by PHP > 5.3.0)
$upload_ext_img = array('jpg', 'jpeg', 'jpc', 'jp2', 'jpx', 'gif', 'png', 'bmp', 'tif', 'tiff');

// Other files allowed
$upload_ext_doc = array('doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', 'odt', 'ott', 'ods', 'ots', 'odp', 'otp', 'zip', 'rar', '7z', 'pdf', 'txt', 'ini');

/*****************************/
/****  END CONFIGURATION  ****/
/*****************************/

// FluxBB
define('PUN_ROOT', dirname(__FILE__).'/');
require PUN_ROOT.'include/common.php';

// Language
if (file_exists(PUN_ROOT.'lang/'.$pun_user['language'].'/upload.php'))
	require PUN_ROOT.'lang/'.$pun_user['language'].'/upload.php';
else
	require PUN_ROOT.'lang/English/upload.php';

// Maintenance mode ?
if (MAINTENANCE && $pun_user['g_id'] != PUN_ADMIN)
	message($lang_upload['ErrMaintenance'], false, '403 Forbidden');

// Guest ?
if ($pun_user['is_guest'])
	message($lang_common['No permission'], false, '403 Forbidden');

// File upload is enabled in PHP ?
if (!ini_get('file_uploads'))
	message($lang_upload['ErrConfigPHP'], false);

// Check version of FluxBB File Uploader
if (!isset($pun_config['o_fluxbbfu_version']) && !$db->table_exists('uploads'))
	$_REQUEST['action'] = 'install';
elseif (version_compare(FFU_VERSION, $pun_config['o_fluxbbfu_version']) > 0)
	$_REQUEST['action'] = 'update';
elseif (!file_exists(PUN_ROOT.UPLOAD_ROOT) || !is_writable(PUN_ROOT.UPLOAD_ROOT))
	message($lang_upload['ErrUploadRoot'], false);

// Action to do
$actions = array(
	'index' => 'user',
	'add' => 'user',
	'manage' => 'user',
	'delete' => 'user',
	'bbcode' => 'user',
	'upload' => 'user',
	'config' => 'admin',
	'install' => 'admin',
	'update' => 'admin'
	);

if (!isset($_REQUEST['action']) || !array_key_exists($_REQUEST['action'], $actions))
	$_REQUEST['action'] = 'index';

// if update/install and user is not an admin
if (($_REQUEST['action'] == 'install' || $_REQUEST['action'] == 'update') && $pun_user['g_id'] != PUN_ADMIN)
	message($lang_upload['ErrMaintenance'], false, '403 Forbidden');

// Admin area ?
if ($actions[$_REQUEST['action']] == admin && $pun_user['g_id'] != PUN_ADMIN)
	message($lang_common['No permission'], false, '403 Forbidden');

// A file was uploaded
if ($_REQUEST['action'] == 'upload' && isset($_FILES['userfile']))
{
	// Errors
	switch ($_FILES['userfile']['error'])
	{
		case 1: // UPLOAD_ERR_INI_SIZE
			message($lang_upload['ErrSizeMaxPHP'], false);
		case 2: // UPLOAD_ERR_FORM_SIZE
			message($lang_upload['ErrSizeMaxAdmin'], false);
		case 3: // UPLOAD_ERR_PARTIAL
			message($lang_upload['ErrFilePartial'], false);
		case 4: // UPLOAD_ERR_NO_FILE
			message($lang_upload['ErrNoFile'], false);
		case 6: // UPLOAD_ERR_NO_TMP_DIR (since PHP 5.0.3)
			message($lang_upload['ErrNoTmpDir'], false);
		case 7: // UPLOAD_ERR_CANT_WRITE (since PHP 5.1.0)
			message($lang_upload['ErrCantWrite'], false);
		case 8: // UPLOAD_ERR_EXTENSION (since PHP 5.2.0)
			message($lang_upload['ErrExtension'], false);
	}

	// Get file info
	$upload_file_time = time();
	$upload_file_name = basename($_FILES['userfile']['name']);
	$upload_file_tmp = $_FILES['userfile']['tmp_name'];
	$upload_file_size = filesize($upload_file_tmp);
	$upload_file_ext = strtolower(substr(strrchr($upload_file_name, '.'), 1));

	// Is an uploaded file ?
	if (!is_uploaded_file($upload_file_tmp))
		message($lang_upload['ErrFileForm'], false);

	// Max size
	if ($upload_file_size > UPLOAD_MAX_SIZE)
		message($lang_upload['ErrSizeMaxAdmin'], false);

	// Min size
	if ($upload_file_size < 1 || $upload_file_size < UPLOAD_MIN_SIZE)
		message($lang_upload['ErrSizeMinAdmin'], false);

	// Filename
	$upload_file_name = preg_replace('#[\x00-\x1f]#', '', $upload_file_name);
	$upload_file_name = preg_replace('#[@=\\\'/ ]+#', '_', $upload_file_name);

	// Type (by extension)
	if (!in_array($upload_file_ext, $upload_ext_img) && !in_array($upload_file_ext, $upload_ext_doc))
		message($lang_upload['ErrFileNotAllowed'], false);

	// If the file in an image
	if (in_array($upload_file_ext, $upload_ext_img))
	{
		$upload_file_dim = getimagesize($upload_file_tmp);

		if (!$upload_file_dim || empty($upload_file_dim[0]) || empty($upload_file_dim[1]))
			message($lang_upload['ErrUploadFailed'], true);

		if ($upload_file_dim[0] > IMG_MAX_WIDTH || $upload_file_dim[1] > IMG_MAX_HEIGHT)
			message(sprintf($lang_upload['ErrImgSize'], forum_number_format(IMG_MAX_WIDTH), forum_number_format(IMG_MAX_HEIGHT)), false);
	}

	// Rename file ?
	if (RENAME_FILE)
	{
		do
		{
			$upload_file_dest = md5(uniqid(mt_rand().$upload_file_time, true)).'.'.$upload_file_ext;
		}
		while (file_exists(PUN_ROOT.UPLOAD_ROOT.$upload_file_dest));
	}
	else
	{
		$upload_file_dest = $upload_file_name;

		if (file_exists(PUN_ROOT.UPLOAD_ROOT.$upload_file_dest))
			message($lang_upload['ErrFileExists'], false);
	}

	// Copy file
	if(!move_uploaded_file($upload_file_tmp, PUN_ROOT.UPLOAD_ROOT.$upload_file_dest))
		message($lang_upload['ErrUploadFailed'], false);

	// Change chmod
	@chmod(PUN_ROOT.UPLOAD_ROOT.$upload_file_dest, 0644);

	// Update database
	$db->query('INSERT INTO '.$db->prefix.'uploads (up_user, up_init, up_dest, up_time) VALUES ('.$pun_user['id'].', \''.$db->escape($upload_file_name).'\', \''.$db->escape($upload_file_dest).'\', '.$upload_file_time.')') or error('Unable to add upload', __FILE__, __LINE__, $db->error());

	// Create BBCode
	if (in_array($upload_file_ext, $upload_ext_img))
		$upload_file_bbcode = '[img='.pun_htmlspecialchars($upload_file_name).']'.get_base_url().'/'.UPLOAD_ROOT.pun_htmlspecialchars($upload_file_dest).'[/img]';
	else
		$upload_file_bbcode = '[url='.get_base_url().'/'.UPLOAD_ROOT.pun_htmlspecialchars($upload_file_dest).']'.pun_htmlspecialchars($upload_file_name).'[/url]';

	// Successfully uploaded !
	message(sprintf($lang_upload['MsgSuccessUpload'], $upload_file_bbcode), true);
}

// Display BBCode of an existing file
if ($_REQUEST['action'] == 'bbcode')
{
	$_GET['file'] = intval($_GET['file']);

	$result = $db->query('SELECT up_init, up_dest FROM '.$db->prefix.'uploads WHERE up_id='.$_GET['file']) or error('Unable to fetch file list', __FILE__, __LINE__, $db->error());

	if (!$db->num_rows($result))
		message($lang_upload['ErrFileNotExist'], false);

	$cur_file = $db->fetch_assoc($result);
	$cur_file['up_ext'] = strtolower(substr(strrchr($cur_file['up_dest'], '.'), 1));

	if (in_array($cur_file['up_ext'], $upload_ext_img))
		$cur_file['up_bbcode'] = '[img='.pun_htmlspecialchars($cur_file['up_init']).']'.get_base_url().'/'.UPLOAD_ROOT.pun_htmlspecialchars($cur_file['up_dest']).'[/img]';
	else
		$cur_file['up_bbcode'] = '[url='.get_base_url().'/'.UPLOAD_ROOT.pun_htmlspecialchars($cur_file['up_dest']).']'.pun_htmlspecialchars($cur_file['up_init']).'[/url]';

	message(sprintf($lang_upload['MsgBBCodeComply'], $cur_file['up_bbcode']), false);
}

// Delete file
if ($_REQUEST['action'] == 'delete' && isset($_POST['file']))
{
	if (!ALLOW_USER_DELETE_OWN_FILES)
		message($lang_upload['ErrUserCantDelete'], true);

	$_POST['file'] = intval($_POST['file']);

	$result = $db->query('SELECT up_id, up_user, up_dest FROM '.$db->prefix.'uploads WHERE up_id='.$_POST['file']) or error('Unable to fetch file info', __FILE__, __LINE__, $db->error());

	if (!$db->num_rows($result))
		message($lang_upload['ErrFileNotExist'], true);

	$cur_file = $db->fetch_assoc($result);

	// Are you the owner of the file ?
	if ($cur_file['up_user'] != $pun_user['id'])
		message($lang_upload['ErrUserCantDelete'], true);

	// If false, the file mustn't be in use
	if (!ALLOW_DELETE_FILE_IN_USE)
	{
		$result = $db->query('SELECT id FROM '.$db->prefix.'posts WHERE message LIKE \'%'.$cur_file['up_dest'].'%\'') or error('Unable to check if the file is in use', __FILE__, __LINE__, $db->error());

		if ($db->num_rows($result) > 0)
			message($lang_upload['ErrFileIsUsed'], true);
	}

	// Clear database and delete file in directory
	$db->query('DELETE FROM '.$db->prefix.'uploads WHERE up_id='.$cur_file['up_id']) or error('Unable to delete file', __FILE__, __LINE__, $db->error());
	@unlink(PUN_ROOT.UPLOAD_ROOT.$cur_file['up_dest']);

	// Successfully deleted !
	redirect('upload.php?action=manage', $lang_upload['MsgSuccessDelete']);
}

// Install
if ($_REQUEST['action'] == 'install' && isset($_POST['install']))
{
	$schema = array(
		'FIELDS'		=> array(
			'up_id'			=> array(
				'datatype'		=> 'SERIAL',
				'allow_null'	=> false
			),
			'up_user'	=> array(
				'datatype'		=> 'INT(10) UNSIGNED',
				'allow_null'	=> false,
				'default'		=> '0'
			),
			'up_init'	=> array(
				'datatype'		=> 'VARCHAR(255)',
				'allow_null'	=> true
			),
			'up_dest'		=> array(
				'datatype'		=> 'VARCHAR(255)',
				'allow_null'	=> true
			),
			'up_time'	=> array(
				'datatype'		=> 'INT(10) UNSIGNED',
				'allow_null'	=> false,
				'default'		=> '0'
			)
		),
		'PRIMARY KEY'	=> array('up_id')
	);

	$db->create_table('uploads', $schema) or error('Unable to create uploads table', __FILE__, __LINE__, $db->error());

	if (!isset($pun_config['o_fluxbbfu_version']))
		$db->query('INSERT INTO '.$db->prefix.'config (conf_name, conf_value) VALUES (\'o_fluxbbfu_version\', \''.FFU_VERSION.'\')') or error('Unable to add new version', __FILE__, __LINE__, $db->error());
	else
		$db->query('UPDATE '.$db->prefix.'config SET conf_value=\''.FFU_VERSION.'\' WHERE '.$db->prefix.'config.conf_name=\'o_fluxbbfu_version\'') or error('Unable to update new version', __FILE__, __LINE__, $db->error());

	// Regenerate the config cache
	if (!defined('FORUM_CACHE_FUNCTIONS_LOADED'))
		require PUN_ROOT.'include/cache.php';

	generate_config_cache();

	// Successfully installed !
	message(sprintf($lang_upload['MsgSuccessInstall'], FFU_VERSION), false);
}

// Update
if ($_REQUEST['action'] == 'update' && isset($_POST['update']))
{
	if ($db->field_exists('uploads', 'id'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE id up_id INT(10) UNSIGNED NOT NULL AUTO_INCREMENT') or error('Unable to alter field \'id\'', __FILE__, __LINE__, $db->error());

	if ($db->field_exists('uploads', 'user_id'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE user_id up_user INT(10) UNSIGNED NOT NULL DEFAULT \'0\'') or error('Unable to alter field \'user_id\'', __FILE__, __LINE__, $db->error());

	if ($db->field_exists('uploads', 'file_init'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE file_init up_init VARCHAR(255) CHARACTER SET UTF8 COLLATE utf8_general_ci NULL DEFAULT NULL') or error('Unable to alter field \'file_init\'', __FILE__, __LINE__, $db->error());

	if ($db->field_exists('uploads', 'file_upload'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE file_upload up_dest VARCHAR(255) CHARACTER SET UTF8 COLLATE utf8_general_ci NULL DEFAULT NULL') or error('Unable to alter field \'file_upload\'', __FILE__, __LINE__, $db->error());

	if ($db->field_exists('uploads', 'file_date'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE file_date up_time INT(10) UNSIGNED NOT NULL DEFAULT \'0\'') or error('Unable to alter field \'file_date\'', __FILE__, __LINE__, $db->error());

	if ($db->field_exists('uploads', 'up_date'))
		$db->query('ALTER TABLE '.$db->prefix.'uploads CHANGE up_date up_time INT(10) UNSIGNED NOT NULL DEFAULT \'0\'') or error('Unable to alter field \'up_date\'', __FILE__, __LINE__, $db->error());

	if (!file_exists(PUN_ROOT.UPLOAD_ROOT))
		mkdir(PUN_ROOT.UPLOAD_ROOT);

	@chmod(PUN_ROOT.UPLOAD_ROOT, 0755);

	if (!isset($pun_config['o_fluxbbfu_version']))
		$db->query('INSERT INTO '.$db->prefix.'config (conf_name, conf_value) VALUES (\'o_fluxbbfu_version\', \''.FFU_VERSION.'\')') or error('Unable to add new version', __FILE__, __LINE__, $db->error());
	else
		$db->query('UPDATE '.$db->prefix.'config SET conf_value=\''.FFU_VERSION.'\' WHERE '.$db->prefix.'config.conf_name=\'o_fluxbbfu_version\'') or error('Unable to update new version', __FILE__, __LINE__, $db->error());

	// Regenerate the config cache
	if (!defined('FORUM_CACHE_FUNCTIONS_LOADED'))
		require PUN_ROOT.'include/cache.php';

	generate_config_cache();

	// Successfully updated !
	message(sprintf($lang_upload['MsgSuccessUpdate'], FFU_VERSION), false);
}

// Display a page
$page_title = array(pun_htmlspecialchars($pun_config['o_board_title']), $lang_upload['Title']);
define('PUN_ACTIVE_PAGE', 'uploads');
require PUN_ROOT.'header.php';

// Install or Update page
if ($_REQUEST['action'] == 'update' || $_REQUEST['action'] == 'install')
{

?>

<div class="blockform">

	<h2><span><?php if ($_REQUEST['action'] == 'update') echo $lang_upload['Update']; else echo $lang_upload['Install']; ?></span></h2>

	<div class="box">
		<form id="<?php echo $_REQUEST['action'] ?>" method="post" action="upload.php">
			<input type="hidden" name="action" value="<?php echo $_REQUEST['action'] ?>" />
			<div class="inform">
				<div class="forminfo">
					<p><?php if ($_REQUEST['action'] == 'update') echo $lang_upload['MsgUpdateComply']; else echo $lang_upload['MsgInstallComply']; ?></p>
				</div>
			</div>
			<p class="buttons"><input type="submit" name="<?php echo $_REQUEST['action'] ?>" value="<?php if ($_REQUEST['action'] == 'update') echo $lang_upload['UpdateButton']; else echo $lang_upload['InstallButton']; ?>" /></p>
		</form>
	</div>

	<div class="clearer"></div>

</div>

<?php

require PUN_ROOT.'footer.php';

}

?>

<div class="block2col">

	<div class="blockmenu">
		<h2><span><?php echo $lang_upload['MenuFile'] ?></span></h2>
		<div class="box">
			<div class="inbox">
				<ul>
					<li<?php if ($_REQUEST['action'] == 'add') echo ' class="isactive"'; ?>><a href="upload.php?action=add"><?php echo $lang_upload['MenuAdd'] ?></a></li>
					<li<?php if ($_REQUEST['action'] == 'manage') echo ' class="isactive"'; ?>><a href="upload.php?action=manage"><?php echo $lang_upload['MenuManage'] ?></a></li>
				</ul>
			</div>
		</div>

<?php

if ($pun_user['g_id'] == PUN_ADMIN)
{

?>

		<h2><span><?php echo $lang_upload['MenuAdmin'] ?></span></h2>
		<div class="box">
			<div class="inbox">
				<ul>
					<li<?php if ($_GET['action'] == 'config') echo ' class="isactive"'; ?>><a href="upload.php?action=config"><?php echo $lang_upload['MenuAConfig'] ?></a></li>
				</ul>
			</div>
		</div>

<?php

}

?>

	</div>

<?php

if ($_REQUEST['action'] == 'index')
{

?>

	<div class="block">
		<h2><span><?php echo $lang_upload['Title'] ?></span></h2>
		<div id="adintro" class="box">
			<div class="inbox">
				<p><?php echo $lang_upload['IdxMsg01'] ?></p>
				<ul>
					<li><span><?php echo $lang_upload['IdxMsg02'] ?></span></li>
					<li><span><?php echo $lang_upload['IdxMsg03'] ?></span></li>
				</ul>
				<p><?php echo $lang_upload['IdxMsg04'] ?></p>
				<ul>
					<li><span><?php echo $lang_upload['IdxMsg05'] ?></span></li>
					<li><span><?php echo $lang_upload['IdxMsg06'] ?></span></li>
				</ul>
				<?php if (MAINTENANCE) echo '<p class="warntext" style="color:#ff0000">',$lang_common['Maintenance mode enabled'],'</p>' ?>
				<p style="font-style:italic;"><?php echo sprintf($lang_common['Powered by'], '<a href="http://fluxbb.org/resources/mods/fluxbb-file-uploader/">FluxBB File Uploader</a>') ?></p>
			</div>
		</div>
	</div>

<?php

}

elseif ($_REQUEST['action'] == 'manage')
{
	// Create pagination
	$page = (!isset($_GET['p']) || intval($_GET['p']) < 1) ? 1 : intval($_GET['p']);

	$result = $db->query('SELECT COUNT(*) FROM '.$db->prefix.'uploads WHERE up_user='.$pun_user['id']) or error("Unable to count the files", __FILE__, __LINE__, $db->error());
	list($num_files) = $db->fetch_row($result);

	$num_pages = ceil($num_files / $pun_config['o_disp_posts_default']);

	if ($page > $num_pages)
		$page = 1;

	$start = intval($pun_config['o_disp_posts_default']) * ($page - 1);
	$limit = $start.','.$pun_config['o_disp_posts_default'];

?>

	<div class="block">
		<h2><span><?php echo $lang_upload['MenuManage'].' ( '.$num_files.' )' ?></span></h2>
		<div class="blocktable">
			<div class="box">
				<div class="inbox">
					<table class="aligntop" cellspacing="0">
					<thead>
						<tr>
							<th class="tcl" scope="col" style="width:45%"><?php echo $lang_upload['MyFiles'] ?></th>
							<th class="tc2" scope="col" style="width:15%"><?php echo $lang_upload['Size'] ?></th>
							<th class="tc2" scope="col" style="width:20%"><?php echo $lang_upload['Added'] ?></th>
							<th class="tc2" scope="col" style="width:20%"><?php echo $lang_upload['Actions'] ?></th>
						</tr>
					</thead>
					<tbody>

<?php

	$result = $db->query('SELECT up_id, up_init, up_dest, up_time FROM '.$db->prefix.'uploads WHERE up_user='.$pun_user['id'].' ORDER BY up_time DESC LIMIT '.$limit ) or error('Unable to fetch file list', __FILE__, __LINE__, $db->error());

	while ($cur_file = $db->fetch_assoc($result))
	{
		$cur_file['up_time'] = format_time($cur_file['up_time']);
		$cur_file['up_size'] = forum_number_format(filesize(UPLOAD_ROOT.$cur_file['up_dest']));

		if (!ALLOW_USER_DELETE_OWN_FILES)
			$cur_file['up_delete'] = null;
		else
			$cur_file['up_delete'] = '<a href="upload.php?action=delete&amp;file='.$cur_file['up_id'].'">'.$lang_upload['Delete'].'</a> - ';

?>

					<tr class="rowodd">
						<td class="tcl"><div class="tclcon"><?php echo $cur_file['up_init'] ?></div></td>
						<td class="tc2"><?php echo $cur_file['up_size'] ?></td>
						<td class="tc2"><?php echo $cur_file['up_time'] ?></td>
						<td class="tc2">
							<?php echo $cur_file['up_delete'] ?>
							<a href="upload.php?action=bbcode&amp;file=<?php echo $cur_file['up_id'] ?>">BBCode</a>
						</td>
					</tr>

<?php

	}

?>

					</tbody>
					</table>
				</div>
			</div>
		</div>

		<div class="pagepost">
			<p class="pagelink conl"><span class="pages-label"><?php echo $lang_common['Pages'].' '.paginate($num_pages, $page, 'upload.php?action=manage') ?></span></p>
		</div>

	</div>

<?php

}

elseif ($_REQUEST['action'] == 'delete' && isset($_GET['file']))
{
	$_GET['file'] = intval($_GET['file']);

?>

	<div class="blockform">
		<h2><span><?php echo $lang_upload['DeleteFile']?></span></h2>
		<div class="box">
			<form id="deletefile" method="post" action="upload.php">
				<input type="hidden" name="action" value="delete" />
				<input type="hidden" name="file" value="<?php echo $_GET['file'] ?>" />
				<div class="inform">
					<div class="forminfo">
						<p><?php echo $lang_upload['MsgDeleteComply'] ?></p>
					</div>
				</div>
				<p class="buttons"><input type="submit" name="delete" value="<?php echo $lang_upload['Delete'] ?>" /> <a href="javascript:history.go(-1)"><?php echo $lang_common['Go back'] ?></a></p>
			</form>
		</div>

	</div>

<?php

}

elseif ($_REQUEST['action'] == 'config')
{

?>

	<div class="block">

		<h2><span><?php echo $lang_upload['CfgTitle'].' '.FFU_VERSION ?></span></h2>
		<div id="adstats" class="box">
			<div class="inbox">
				<p><?php echo $lang_upload['CfgInfo'] ?></p>
				<dl>
					<dt style="width:19em">UPLOAD_ROOT</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo UPLOAD_ROOT ?>
					</dd>
					<dt style="width:19em">UPLOAD_MIN_SIZE</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo forum_number_format(UPLOAD_MIN_SIZE) ?>
					</dd>
					<dt style="width:19em">UPLOAD_MAX_SIZE</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo forum_number_format(UPLOAD_MAX_SIZE) ?>
					</dd>
					<dt style="width:19em">IMG_MAX_WIDTH</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo forum_number_format(IMG_MAX_WIDTH) ?>
					</dd>
					<dt style="width:19em">IMG_MAX_HEIGHT</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo forum_number_format(IMG_MAX_HEIGHT) ?>
					</dd>
					<dt style="width:19em">RENAME_FILE</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo((RENAME_FILE == true) ? 'true' : 'false') ?>
					</dd>
					<dt style="width:19em">ALLOW_USER_DELETE_OWN_FILES</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo((ALLOW_USER_DELETE_OWN_FILES == true) ? 'true' : 'false') ?>
					</dd>
					<dt style="width:19em">ALLOW_DELETE_FILE_IN_USE</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo((ALLOW_DELETE_FILE_IN_USE == true) ? 'true' : 'false') ?>
					</dd>
					<dt style="width:19em"><?php echo $lang_upload['CfgImgAllowed'] ?></dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php for ($i = 0; $i < count($upload_ext_img); $i++) echo $upload_ext_img[$i].' - ' ?>
					</dd>
					<dt style="width:19em"><?php echo $lang_upload['CfgDocAllowed'] ?></dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php for ($i = 0; $i < count($upload_ext_doc); $i++) echo $upload_ext_doc[$i].' - ' ?>
					</dd>
				</dl>
			</div>
		</div>

		<h2 class="block2"><span><?php echo $lang_upload['CfgPHPConfig'] ?></h2>
		<div id="adstats" class="box">
			<div class="inbox">
				<dl>
					<dt style="width:19em">upload_max_filesize</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo ini_get('upload_max_filesize') ?>
					</dd>
					<dt style="width:19em">post_max_size</dt>
					<dd style="padding-left:19em">
						=&nbsp;<?php echo ini_get('post_max_size') ?>
					</dd>
				</dl>
			</div>
		</div>

	</div>

<?php

}

elseif ($_REQUEST['action'] == 'add')
{

?>

	<div class="blockform">

		<h2><span><?php echo $lang_upload['AddFile']?></span></h2>
		<div class="box">
			<form id="uploadfile" action="upload.php" enctype="multipart/form-data" method="post">
				<div class="inform">
					<fieldset>
						<legend><?php echo $lang_upload['SelectFile'] ?></legend>
						<div class="infldset">
							<label class="conl">
								<input type="hidden" name="action" value="upload" />
								<input type="hidden" name="MAX_FILE_SIZE" value="<?php echo UPLOAD_MAX_SIZE; ?>">
								<input type="file" name="userfile" />
							</label>
							<p class="buttons">
								<input type="submit" value="<?php echo $lang_upload['UploadFile']; ?>" />
							</p>
						</div>
					</fieldset>
				</div>
			</form>
		</div>

	</div>

<?php

}

elseif ($_REQUEST['action'] == 'install')
{

?>

	<div class="blockform">
		<h2><span><?php echo $lang_upload['DeleteFile']?></span></h2>
		<div class="box">
			<form method="post" action="upload.php">
				<input type="hidden" name="action" value="install" />
				<input type="hidden" name="install" value="1" />
				<div class="inform">
					<div class="forminfo">
						<p><?php echo $lang_upload['MsgDeleteComply'] ?></p>
					</div>
				</div>
			<p class="buttons"><input type="submit" name="delete" value="<?php echo $lang_upload['Delete'] ?>" /> <a href="javascript:history.go(-1)"><?php echo $lang_common['Go back'] ?></a></p>
		</form>
	</div>

<?php

}

?>

	<div class="clearer"></div>

</div>

<?php

require PUN_ROOT.'footer.php';
